@@ -32,7 +32,7 @@ public:
     ~Layers() override;
 
     // inherited from DocumentObserver
-    void notifySetup(const QVector<Okular::Page *> &pages, int setupFlags) override;
+    void notifySetup(const QList<Okular::Page *> &pages, int setupFlags) override;
 
     void setPageView(PageView *pageView);
 
